@@ -115,7 +115,7 @@ class gSheet:
                 spreadsheetId=self.sheet_id,
                 body=request_body
                 ).execute()
-
+            self.load_page_info()
             return response
 
         # escape code for duplicate name error
@@ -176,7 +176,7 @@ class gSheet:
                 spreadsheetId=self.sheet_id,
                 body=request_body
                 ).execute()
-
+            self.load_page_info()
             return response
 
         # escape code for duplicate name error
@@ -193,8 +193,8 @@ class gSheet:
         request_body = {
             'requests': [
                     {
-                    'delete_page': 
-                        {'sheetId': self.page_names[page_name]['sheetId']}
+                    'deleteSheet': 
+                        {'sheetId': self.page_info[page_name]['sheetId']}
                     }
                 ]
             }
@@ -204,7 +204,7 @@ class gSheet:
                 spreadsheetId=self.sheet_id,
                 body=request_body
                 ).execute()
-
+            self.load_page_info()
             return response
 
         # escape code for duplicate name error
